<?php

namespace Litematrimony\Profile\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litematrimony\Profile\Models\Profile;


class ProfileAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Profile $profile, array $request = [])
    {
        $this->model = $profile;

        $function = Str::camel($action);
        event('litematrimony.profile.profile.action.' . $action . 'ing', [$profile]);
        $data =  $this->$function($profile, $request);
        event('litematrimony.profile.profile.action.' . $action . 'ed', [$profile]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Profile $profile, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $profile = $profile->create($attributes);
        return $profile;
    }

    public function update(Profile $profile, array $request)
    {
        $attributes = $request;
        $profile->update($attributes);
        return $profile;
    }

    public function destroy(Profile $profile, array $request)
    {
        $profile->delete();
        return $profile;
    }

    public function copy(Profile $profile, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $profile = $profile->replicate();
            $profile->created_at = Carbon::now();
            $profile->save();
            return $profile;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $profile->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $profile;
    }


}
