<?php

namespace Litematrimony\Profile\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litematrimony\Profile\Models\Shortlist;


class ShortlistAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Shortlist $shortlist, array $request = [])
    {
        $this->model = $shortlist;

        $function = Str::camel($action);
        event('litematrimony.profile.shortlist.action.' . $action . 'ing', [$shortlist]);
        $data =  $this->$function($shortlist, $request);
        event('litematrimony.profile.shortlist.action.' . $action . 'ed', [$shortlist]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Shortlist $shortlist, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $shortlist = $shortlist->create($attributes);
        return $shortlist;
    }

    public function update(Shortlist $shortlist, array $request)
    {
        $attributes = $request;
        $shortlist->update($attributes);
        return $shortlist;
    }

    public function destroy(Shortlist $shortlist, array $request)
    {
        $shortlist->delete();
        return $shortlist;
    }

    public function copy(Shortlist $shortlist, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $shortlist = $shortlist->replicate();
            $shortlist->created_at = Carbon::now();
            $shortlist->save();
            return $shortlist;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $shortlist->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $shortlist;
    }


}
