<?php

namespace Litematrimony\Profile\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litematrimony\Profile\Models\Visit;


class VisitAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Visit $visit, array $request = [])
    {
        $this->model = $visit;

        $function = Str::camel($action);
        event('litematrimony.profile.visit.action.' . $action . 'ing', [$visit]);
        $data =  $this->$function($visit, $request);
        event('litematrimony.profile.visit.action.' . $action . 'ed', [$visit]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Visit $visit, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $visit = $visit->create($attributes);
        return $visit;
    }

    public function update(Visit $visit, array $request)
    {
        $attributes = $request;
        $visit->update($attributes);
        return $visit;
    }

    public function destroy(Visit $visit, array $request)
    {
        $visit->delete();
        return $visit;
    }

    public function copy(Visit $visit, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $visit = $visit->replicate();
            $visit->created_at = Carbon::now();
            $visit->save();
            return $visit;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $visit->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $visit;
    }


}
