<?php

namespace Litematrimony\Profile\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Litematrimony\Profile\Actions\ProfileExim;
use Litematrimony\Profile\Http\Requests\ProfileEximRequest;

/**
 * Admin web controller class.
 */
class ProfileEximController extends BaseController
{
    /**
     * Action controller function for profile.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ProfileEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = ProfileExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('profile:profile.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('profile/profile/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('profile/profile/' . $exim))
                ->redirect();
        }
    }
}
