<?php

namespace Litematrimony\Profile\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litematrimony\Profile\Http\Requests\RequestActionsRequest;
use Litematrimony\Profile\Models\RequestActions;

/**
 * Admin web controller class.
 */
class RequestActionsController extends BaseController
{

    /**
     * Action controller function for request.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(RequestActionsRequest $request, $action)
    {
        try {
            $request = RequestActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('profile::request.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('profile/request/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('profile/request/' . $action))
                ->redirect();
        }
    }
}
