<?php

namespace Litematrimony\Profile\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litematrimony\Profile\Http\Resources\ProfileResource;
use Litematrimony\Profile\Http\Resources\ProfilesCollection;
use Litematrimony\Profile\Scopes\RequestPublicScope;
use Litematrimony\Profile\Models\Request;

class RequestPublicController extends BaseController
{

    /**
     * Show request's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Request::pushScope(new RequestScope())
            ->pushScope(new RequestPublicScope())
            ->select('requests.*')
            ->paginate($pageLimit)
            ->withQueryString();

        $data = new RequestsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('profile::request.names'))
            ->view('profile::public.request.index')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show request.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Request::findBySlug($slug);
        $data = new RequestResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('profile::request.name'))
            ->view('profile::public.request.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
