<?php

namespace Litematrimony\Profile\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litematrimony\Profile\Actions\ShortlistAction;
use Litematrimony\Profile\Http\Requests\ShortlistActionRequest;
use Litematrimony\Profile\Http\Resources\ShortlistResource;
use Litematrimony\Profile\Models\Shortlist;

/**
 * Admin web controller class.
 */
class ShortlistActionController extends BaseController
{

    /**
     * Action controller function for shortlist.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ShortlistActionRequest $request, Shortlist $shortlist, $action)
    {
        try {
            $shortlist = ShortlistAction::run($request, $shortlist, $action);

            $data = new ShortlistResource($shortlist);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('profile::shortlist.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('profile/shortlist/' . $shortlist->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('profile/shortlist/' . $shortlist->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
