<?php

namespace Litematrimony\Profile\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litematrimony\Profile\Http\Resources\ProfileResource;
use Litematrimony\Profile\Http\Resources\ProfilesCollection;
use Litematrimony\Profile\Scopes\ShortlistPublicScope;
use Litematrimony\Profile\Models\Shortlist;

class ShortlistPublicController extends BaseController
{

    /**
     * Show shortlist's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Shortlist::pushScope(new RequestScope())
            ->pushScope(new ShortlistPublicScope())
            ->select('shortlists.*')
            ->paginate($pageLimit)
            ->withQueryString();

        $data = new ShortlistsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('profile::shortlist.names'))
            ->view('profile::public.shortlist.index')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show shortlist.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Shortlist::findBySlug($slug);
        $data = new ShortlistResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('profile::shortlist.name'))
            ->view('profile::public.shortlist.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
