<?php

namespace Litematrimony\Profile\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litematrimony\Profile\Actions\VisitAction;
use Litematrimony\Profile\Http\Requests\VisitActionRequest;
use Litematrimony\Profile\Http\Resources\VisitResource;
use Litematrimony\Profile\Models\Visit;

/**
 * Admin web controller class.
 */
class VisitActionController extends BaseController
{

    /**
     * Action controller function for visit.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(VisitActionRequest $request, Visit $visit, $action)
    {
        try {
            $visit = VisitAction::run($request, $visit, $action);

            $data = new VisitResource($visit);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('profile::visit.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('profile/visit/' . $visit->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('profile/visit/' . $visit->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
