<?php

namespace Litematrimony\Profile\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litematrimony\Profile\Http\Resources\ProfileResource;
use Litematrimony\Profile\Http\Resources\ProfilesCollection;
use Litematrimony\Profile\Scopes\VisitPublicScope;
use Litematrimony\Profile\Models\Visit;

class VisitPublicController extends BaseController
{

    /**
     * Show visit's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Visit::pushScope(new RequestScope())
            ->pushScope(new VisitPublicScope())
            ->select('visits.*')
            ->paginate($pageLimit)
            ->withQueryString();

        $data = new VisitsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('profile::visit.names'))
            ->view('profile::public.visit.index')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show visit.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Visit::findBySlug($slug);
        $data = new VisitResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('profile::visit.name'))
            ->view('profile::public.visit.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
