<?php

namespace Litematrimony\Profile\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litematrimony\Profile\Events\ShortlistAction as ShortlistActionEvent;
use Litematrimony\Profile\Notifications\ShortlistAction as ShortlistActionNotification;
use Litepie\Actions\Concerns\AsAction;

class ShortlistAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the ShortlistActionEvent.
     *
     * @param   ShortlistActionEvent  $event
     * @return mixed
     */
    public function handle(ShortlistActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $shortlist.
     *
     * @param   ShortlistActionEvent  $event
     * @return void
     */
    public function create(ShortlistActionEvent $event)
    {
        $client = $event->$shortlist->client;
        Notification::send($client, new ShortlistActionNotification($event));
    }

    /**
     * Handle the ShortlistActionEvent as a listener.
     *
     * @param   ShortlistActionEvent  $event
     * @return mixed
     */
    public function asListener(ShortlistActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   ShortlistActionEvent  $event
     * @return bool
     */
    private function isAllowed(ShortlistActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
