<?php

namespace Litematrimony\Profile\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litematrimony\Profile\Events\ShortlistWorkflow as ShortlistWorkflowEvent;
use Litematrimony\Profile\Notifications\ShortlistWorkflow as ShortlistWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class ShortlistWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(ShortlistWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $shortlist is submitted.
     *
     * @param ShortlistWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(ShortlistWorkflowEvent $event)
    {
        $client = $event->$shortlist->client;
        Notification::send($client, new ShortlistWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $shortlist is published.
     *
     * @param ShortlistWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(ShortlistWorkflowEvent $event)
    {
        $client = $event->$shortlist->client;
        Notification::send($client, new ShortlistWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $shortlist is approved.
     *
     * @param ShortlistWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(ShortlistWorkflowEvent $event)
    {
        $client = $event->$shortlist->client;
        Notification::send($client, new ShortlistWorkflowNotification($event));
    }

    /**
     * Handles the $shortlist workflow event as a listener.
     *
     * @param ShortlistWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(ShortlistWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
