<?php

namespace Litematrimony\Profile\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litematrimony\Profile\Models\Request;

class RequestPolicy
{

    use RequestAction;

    /**
     * Determine if the given user can view the request.
     *
     * @param UserPolicyInterface $authUser
     * @param Request $request
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Request $request)
    {
        if ($authUser->canDo('profile.request.view') && $authUser->isAdmin()) {
            return true;
        }

        return $request->user_id == user_id() && $request->user_type == user_type();
    }

    /**
     * Determine if the given user can create a request.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('profile.request.create');
    }

    /**
     * Determine if the given user can update the given request.
     *
     * @param UserPolicyInterface $authUser
     * @param Request $request
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Request $request)
    {
        if ($authUser->canDo('profile.request.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $request->user_id == user_id() && $request->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given request.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Request $request)
    {
        return $request->user_id == user_id() && $request->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given request.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Request $request)
    {
        if ($authUser->canDo('profile.request.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given request.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Request $request)
    {
        if ($authUser->canDo('profile.request.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
