<?php

namespace Litematrimony\Profile\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litematrimony\Profile\Models\Shortlist;

class ShortlistPolicy
{

    use ShortlistAction;

    /**
     * Determine if the given user can view the shortlist.
     *
     * @param UserPolicyInterface $authUser
     * @param Shortlist $shortlist
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Shortlist $shortlist)
    {
        if ($authUser->canDo('profile.shortlist.view') && $authUser->isAdmin()) {
            return true;
        }

        return $shortlist->user_id == user_id() && $shortlist->user_type == user_type();
    }

    /**
     * Determine if the given user can create a shortlist.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('profile.shortlist.create');
    }

    /**
     * Determine if the given user can update the given shortlist.
     *
     * @param UserPolicyInterface $authUser
     * @param Shortlist $shortlist
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Shortlist $shortlist)
    {
        if ($authUser->canDo('profile.shortlist.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $shortlist->user_id == user_id() && $shortlist->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given shortlist.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Shortlist $shortlist)
    {
        return $shortlist->user_id == user_id() && $shortlist->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given shortlist.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Shortlist $shortlist)
    {
        if ($authUser->canDo('profile.shortlist.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given shortlist.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Shortlist $shortlist)
    {
        if ($authUser->canDo('profile.shortlist.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
